@@ -7,7 +7,7 @@ import logging
 from abc import ABC
 from collections import namedtuple, defaultdict, deque
 from dataclasses import dataclass, field
-from datetime import datetime, date, time
+from datetime import datetime, date, time, timedelta
 from typing import (
     List, Optional, Union, Tuple, Dict, NamedTuple, Type, DefaultDict,
     Set, FrozenSet, Generic
@@ -16,7 +16,7 @@ from typing import (
 import pytest
 
 from dataclass_wizard import *
-from dataclass_wizard.constants import TAG
+from dataclass_wizard.constants import TAG, PY310_OR_ABOVE
 from dataclass_wizard.errors import ParseError, MissingFields, UnknownJSONKey
 from dataclass_wizard.parsers import OptionalParser, Parser, IdentityParser, SingleArgParser
 from dataclass_wizard.type_def import NoneType, T
@@ -249,6 +249,40 @@ def test_bool(input, expected):
     assert result.my_bool == expected
 
 
+@pytest.mark.skipif(not PY310_OR_ABOVE,
+                    reason="requires Python 3.10 or higher")
+@pytest.mark.parametrize(
+    'input,expectation',
+    [
+        ({'my_field1': 3.1, 'my_field2': []}, pytest.raises(ParseError)),
+        ({'my_field1': 3, 'my_field2': []}, does_not_raise()),
+        ({'my_field1': 'string',
+          'my_field2': [{'date_field': None}]}, does_not_raise()),
+
+    ]
+)
+def test_load_with_py10_features(input, expectation):
+    """
+    Test case using the latest Python 3.10 features, such as PEP 604- style
+    annotations.
+
+    Ref: https://www.python.org/dev/peps/pep-0604/
+    """
+
+    @dataclass
+    class B:
+        date_field: datetime | None
+
+    @dataclass
+    class A(JSONWizard):
+        my_field1: bool | str | int
+        my_field2: list[B]
+
+    with expectation:
+        result = A.from_dict(input)
+        log.debug('Parsed object: %r', result)
+
+
 def test_from_dict_with_missing_fields():
     """
     Calling `from_dict` when required dataclass field(s) are missing in the
@@ -615,6 +649,35 @@ def test_time(input, expectation):
         log.debug('Parsed object: %r', result)
 
 
+@pytest.mark.parametrize(
+    'input,expectation',
+    [
+        ('testing', pytest.raises(ValueError)),
+        ('23:59:59-04:00', pytest.raises(ValueError)),
+        ('32m', does_not_raise()),
+        ('2h32m', does_not_raise()),
+        ('4:13', does_not_raise()),
+        ('5hr34m56s', does_not_raise()),
+        ('1.2 minutes', does_not_raise()),
+        (12345, does_not_raise()),
+        (True, pytest.raises(TypeError)),
+        (timedelta(days=1, seconds=2), does_not_raise()),
+    ]
+)
+def test_timedelta(input, expectation):
+
+    @dataclass
+    class MyClass(JSONSerializable):
+        my_td: timedelta
+
+    d = {'myTD': input}
+
+    with expectation:
+        result = MyClass.from_dict(d)
+        log.debug('Parsed object: %r', result)
+        log.debug('timedelta string value: %s', result.my_td)
+
+
 @pytest.mark.parametrize(
     'input,expectation,expected',
     [
